@@ -2,4 +2,4 @@ import click
 from .cli import cli
 
 def main():
-    cli( obj={ "filters": [] } )
+    cli()
